@@ -82,7 +82,7 @@ def identification_function(
     `[Gneiting2011]`
 
     :   T. Gneiting.
-        "Making and Evaluating Point Forecasts”. (2011)
+        "Making and Evaluating Point Forecasts". (2011)
         [doi:10.1198/jasa.2011.r10138](https://doi.org/10.1198/jasa.2011.r10138)
         [arxiv:0912.0902](https://arxiv.org/abs/0912.0902)
 
@@ -165,7 +165,8 @@ def compute_bias(
     n_bins : int
         The number of bins for numerical features and the maximal number of (most
         frequent) categories shown for categorical features. Due to ties, the effective
-        number of bins might be smaller than `n_bins`.
+        number of bins might be smaller than `n_bins`. Null values are always included
+        in the output, accounting for one bin. NaN values are treated as null values.
 
     Returns
     -------
@@ -195,7 +196,7 @@ def compute_bias(
     This generalises the classical residual (up to a minus sign) for target functionals
     other than the mean. See `[FLM2022]`.
 
-    The standard error for \(\bar{V}\) is caluclated in the standard way as
+    The standard error for \(\bar{V}\) is calculated in the standard way as
     \(\mathrm{SE} = \sqrt{\operatorname{Var}(\bar{V})} = \frac{\sigma}{\sqrt{n}}\) and
     the standard variance estimator for \(\sigma^2 = \operatorname{Var}(\phi(x_i)
     V(m(x_i), y_i))\) with Bessel correction, i.e. division by \(n-1\) instead of
@@ -205,7 +206,7 @@ def compute_bias(
     = \frac{1}{n-1} \frac{1}{\sum_i w_i} \sum_i w_i (V(m(x_i), y_i) - \bar{V})^2\) with
     the implied relation \(\operatorname{Var}(V(m(x_i), y_i)) \sim \frac{1}{w_i} \).
     If your weights are for repeated observations, so-called frequency weights, then
-    the above estimate is on the conservative side because it uses \(n - 1\) instead
+    the above estimate is conservative because it uses \(n - 1\) instead
     of \((\sum_i w_i) - 1\).
 
     References
@@ -255,7 +256,6 @@ def compute_bias(
     df_list = []
     with pl.StringCache():
         is_categorical = False
-        is_numeric = False
         is_string = False
 
         if feature is None:
@@ -272,13 +272,12 @@ def compute_bias(
                 # We could convert strings to categoricals.
                 is_string = True
             elif feature.is_float():
-                is_numeric = True
                 # We treat NaN as Null values, numpy will see a Null as a NaN.
                 if feature.is_float():
                     feature = feature.fill_nan(None)
             else:
                 # integers
-                is_numeric = True
+                pass
 
             if is_categorical or is_string:
                 # For categorical and string features, knowing the frequency table in
@@ -292,16 +291,26 @@ def compute_bias(
                 # with n_bins = 2. As we want the effective number of bins to be at
                 # most n_bins, we want, in the above case, only "a" in the final
                 # result. Therefore, we need to internally decrease n_bins to 1.
-                value_count = feature.value_counts(sort=True)
-                if n_bins >= value_count.shape[0]:
+                if feature.null_count() == 0:
+                    value_count = feature.value_counts(sort=True)
+                    n_bins_ef = n_bins
+                else:
+                    value_count = feature.drop_nulls().value_counts(sort=True)
+                    n_bins_ef = n_bins - 1
+
+                if n_bins_ef >= value_count.shape[0]:
                     n_bins = value_count.shape[0]
                 else:
-                    n = value_count["counts"][n_bins]
+                    n = value_count["counts"][n_bins_ef]
                     n_bins_tmp = value_count.filter(pl.col("counts") >= n).shape[0]
-                    if n_bins_tmp > n_bins:
+                    if n_bins_tmp > n_bins_ef:
                         n_bins = value_count.filter(pl.col("counts") > n).shape[0]
                     else:
                         n_bins = n_bins_tmp
+
+                if feature.null_count() >= 1:
+                    n_bins += 1
+
                 if n_bins == 0:
                     msg = (
                         "Due to ties, the effective number of bins is 0. "
@@ -313,15 +322,19 @@ def compute_bias(
                 # We use method="inverted_cdf" (same as "lower") instead of the
                 # default "linear" because "linear" produces as many unique values
                 # as before.
+                # If we have Null values, we should reserve one bin for it and reduce
+                # the effective number of bins by 1.
+                n_bins_ef = max(1, n_bins - (feature.null_count() >= 1))
                 q = np.nanquantile(
                     feature,
-                    # Improved rounding errors by using integers inside linspace.
-                    q=np.linspace(0 + 1, n_bins - 1, num=n_bins - 1) / n_bins,
+                    # Improved rounding errors by using integers and dividing at the
+                    # end as opposed to np.linspace with 1/n_bins step size.
+                    q=np.arange(1, n_bins_ef) / n_bins_ef,
                     method="inverted_cdf",
-                )  # type: ignore
+                )
                 q = np.unique(q)  # Some quantiles might be the same.
                 # We want: bins[i-1] < x <= bins[i]
-                f_binned = np.digitize(feature, bins=q, right=True)  # type: ignore
+                f_binned = np.digitize(feature, bins=q, right=True)
                 # Now, we insert Null values again at the original places.
                 f_binned = (
                     pl.LazyFrame(
@@ -423,12 +436,20 @@ def compute_bias(
                             .alias("bias_stderr"),
                         ]
                     )
-                    .sort("bias_count", descending=True)
+                    # With sort and head alone, we could lose the null value, but we
+                    # want to keep it.
+                    # .sort("bias_count", descending=True)
+                    # .head(n_bins)
+                    .with_columns(
+                        pl.when(pl.col(feature_name).is_null())
+                        .then(pl.max("bias_count") + 1)
+                        .otherwise(pl.col("bias_count"))
+                        .alias("__priority")
+                    )
+                    .sort("__priority", descending=True)
                     .head(n_bins)
                     .sort(feature_name, descending=False)
                 )
-                if is_numeric:
-                    df = df.drop("bin")
 
                 df = df.select(
                     [
@@ -456,6 +477,8 @@ def compute_bias(
             #   data type. Newer versions of python may behave correctly.
             stderr_ = df.get_column("bias_stderr")
             p_value = np.full_like(stderr_, fill_value=np.nan)
+            n = df.get_column("bias_count")
+            p_value[(n > 1) & (stderr_ == 0)] = 0
             mask = stderr_ > 0
             x = df.get_column("bias_mean").filter(mask).to_numpy()
             n = df.get_column("bias_count").filter(mask).to_numpy()
