@@ -39,7 +39,7 @@ def test_plot_reliability_diagram_raises_y_obs_multdim():
 @pytest.mark.parametrize("ax", [None, plt.subplots()[1]])
 def test_plot_reliability_diagram(diagram_type, n_bootstrap, weights, ax):
     """Test that plot_reliability_diagram works."""
-    X, y = make_classification(random_state=42)
+    X, y = make_classification(random_state=42, n_classes=2)
     if weights is None:
         X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
         w_train, w_test = None, None
@@ -48,7 +48,7 @@ def test_plot_reliability_diagram(diagram_type, n_bootstrap, weights, ax):
         X_train, X_test, y_train, y_test, w_train, w_test = train_test_split(
             X, y, weights, random_state=0
         )
-    clf = LogisticRegression(solver="lbfgs")
+    clf = LogisticRegression(solver="newton-cholesky")
     clf.fit(X_train, y_train, w_train)
     y_pred = clf.predict_proba(X_test)[:, 1]
     plt_ax = plot_reliability_diagram(
@@ -90,6 +90,7 @@ def test_plot_reliability_diagram_multiple_predictions():
     y_obs = np.arange(n_obs)
     y_obs[::2] = 0
     y_pred = pd.DataFrame({"model_2": np.ones(n_obs), "model_1": 3 * np.ones(n_obs)})
+    fig, ax = plt.subplots()
     plt_ax = plot_reliability_diagram(
         y_obs=y_obs,
         y_pred=y_pred,
@@ -151,10 +152,30 @@ def test_plot_reliability_diagram_constant_prediction_transform_output():
         plot_reliability_diagram(y_obs=y_obs, y_pred=y_pred, n_bootstrap=10)
 
 
+def test_plot_bias_warning_for_with_errorbars():
+    """Test that plot_bias gives warning for when some stderr are Null."""
+    y_obs = np.arange(3).astype(float)
+    y_obs[0] = np.nan
+    y_pred = y_obs + 1
+    feature = ["a", "a", "b"]
+
+    with pytest.warns(
+        UserWarning,
+        match="Some values of 'bias_stderr' are null. Therefore no error bars are",
+    ):
+        plot_bias(
+            y_obs=y_obs,
+            y_pred=y_pred,
+            feature=feature,
+            with_errorbars=True,
+        )
+
+
+@pytest.mark.parametrize("with_null_values", [False, True])
 @pytest.mark.parametrize("feature_type", ["cat", "num", "string"])
 @pytest.mark.parametrize("with_errorbars", [False, True])
 @pytest.mark.parametrize("ax", [None, plt.subplots()[1]])
-def test_plot_bias(feature_type, with_errorbars, ax):
+def test_plot_bias(with_null_values, feature_type, with_errorbars, ax):
     """Test that plot_bias works."""
     X, y = make_classification(
         n_samples=100,
@@ -176,30 +197,46 @@ def test_plot_bias(feature_type, with_errorbars, ax):
         bins = np.quantile(feature, [0.2, 0.5, 0.8])
         feature = np.digitize(feature, bins=bins).astype("=U8")
 
-    plt_ax = plot_bias(
-        y_obs=y_test,
-        y_pred=clf.predict_proba(X_test)[:, 1],
-        feature=feature,
-        with_errorbars=with_errorbars,
-        ax=ax,
-    )
+    with pl.StringCache():
+        if with_null_values:
+            if feature_type == "cat":
+                feature = (
+                    pl.Series(feature)
+                    .cast(str)
+                    .set_at_idx(0, None)
+                    .cast(pl.Categorical)
+                )
+            else:
+                feature = pl.Series(feature).set_at_idx(0, None)
 
-    if ax is not None:
-        assert ax is plt_ax
-    if feature_type == "num":
-        assert plt_ax.get_xlabel() == "binned feature"
-    else:
-        assert plt_ax.get_xlabel() == "feature"
-    assert plt_ax.get_ylabel() == "bias"
-    assert plt_ax.get_title() == "Bias Plot"
+        plt_ax = plot_bias(
+            y_obs=y_test,
+            y_pred=clf.predict_proba(X_test)[:, 1],
+            feature=feature,
+            with_errorbars=with_errorbars,
+            ax=ax,
+        )
 
-    plt_ax = plot_bias(
-        y_obs=y_test,
-        y_pred=pd.Series(clf.predict_proba(X_test)[:, 1], name="simple"),
-        feature=feature,
-        with_errorbars=with_errorbars,
-        ax=ax,
-    )
+        if ax is not None:
+            assert ax is plt_ax
+        if feature_type == "num":
+            assert plt_ax.get_xlabel() == "binned feature"
+        else:
+            assert plt_ax.get_xlabel() == "feature"
+        assert plt_ax.get_ylabel() == "bias"
+        assert plt_ax.get_title() == "Bias Plot"
+
+        if with_null_values and feature_type in ["string", "cat"]:
+            xtick_labels = plt_ax.xaxis.get_ticklabels()
+            assert xtick_labels[-1].get_text() == "Null"
+
+        plt_ax = plot_bias(
+            y_obs=y_test,
+            y_pred=pd.Series(clf.predict_proba(X_test)[:, 1], name="simple"),
+            feature=feature,
+            with_errorbars=with_errorbars,
+            ax=ax,
+        )
     assert plt_ax.get_title() == "Bias Plot simple"
 
 
@@ -225,8 +262,10 @@ def test_plot_bias_feature_none():
     ]
 
 
+@pytest.mark.parametrize("with_null", [False, True])
 @pytest.mark.parametrize("feature_type", ["num", "string"])
-def test_plot_bias_multiple_predictions(feature_type):
+@pytest.mark.parametrize("with_errorbars", [False, True])
+def test_plot_bias_multiple_predictions(with_null, feature_type, with_errorbars):
     """Test that plot_bias works for multiple predictions.
 
     This also tests feature to be a string with many different values
@@ -240,21 +279,26 @@ def test_plot_bias_multiple_predictions(feature_type):
             "model_2": (y_obs - 3) ** 2,
         }
     )
-    # string
     rng = np.random.default_rng(42)
     feature = rng.integers(low=0, high=n_obs // 2, size=n_obs)
     if feature_type == "string":
         feature = feature.astype(str)
 
+    if with_null:
+        feature = pl.Series(feature).set_at_idx([0, 5], None)
+
     fig, ax = plt.subplots()
     ax = plot_bias(
         y_obs=y_obs,
         y_pred=y_pred,
         feature=feature,
+        with_errorbars=with_errorbars,
     )
     assert ax.get_title() == "Bias Plot"
     legend_text = ax.get_legend().get_texts()
-    assert len(legend_text) == 3
+    assert len(legend_text) == 3 + with_null
     assert legend_text[0].get_text() == "model_1"
     assert legend_text[1].get_text() == "model_3"
     assert legend_text[2].get_text() == "model_2"
+    if with_null:
+        assert legend_text[3].get_text() == "Null values"
