@@ -1,4 +1,6 @@
+from .plots import plot_murphy_diagram
 from .scoring import (
+    ElementaryScore,
     GammaDeviance,
     HomogeneousExpectileScore,
     HomogeneousQuantileScore,
@@ -10,6 +12,8 @@ from .scoring import (
 )
 
 __all__ = [
+    "plot_murphy_diagram",
+    "ElementaryScore",
     "GammaDeviance",
     "HomogeneousExpectileScore",
     "HomogeneousQuantileScore",
